@@ -9,7 +9,7 @@ use base qw( Exporter );
 our @EXPORT = qw( find_lib assert_lib check_lib check_lib_or_exit find_lib_or_exit );
 
 # ABSTRACT: Check that a library is available for FFI
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 
 our $system_path;
@@ -186,6 +186,18 @@ sub find_lib_or_exit
 }
 
 
+sub find_lib_or_die
+{
+  my(@libs) = find_lib(@_);
+  unless(@libs)
+  {
+    croak $diagnostic || 'library not found';
+  }
+  return unless @libs;
+  wantarray ? @libs : $libs[0];
+}
+
+
 sub check_lib
 {
   find_lib(@_) ? 1 : 0;
@@ -205,7 +217,7 @@ FFI::CheckLib - Check that a library is available for FFI
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -315,6 +327,14 @@ This behaves exactly the same as L<find_lib|FFI::CheckLib#find_lib>,
 except that if the library is not found, it will call exit with an
 appropriate diagnostic.
 
+=head2 find_lib_or_die
+
+[version 0.06]
+
+This behaves exactly the same as L<find_lib|FFI::CheckLib#find_lib>,
+except that if the library is not found, it will die with an
+appropriate diagnostic.
+
 =head2 check_lib
 
 This behaves exactly the same as L<find_lib|FFI::CheckLib#find_lib>, except that
